@@ -1,17 +1,17 @@
 #include "checksumdlg.h"
 #include "../krusader.h"
-#include <klocale.h>
+#include <tdelocale.h>
 #include <tqlayout.h>
 #include <tqlabel.h>
 #include <tqcheckbox.h>
 #include <klineedit.h>
-#include <klistview.h>
+#include <tdelistview.h>
 #include <tqpixmap.h>
 #include <kcursor.h>
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
 #include <tqfile.h>
 #include <tqtextstream.h>
-#include <kfiledialog.h>
+#include <tdefiledialog.h>
 #include <tqframe.h>
 #include <kiconloader.h>
 #include <kcombobox.h>
@@ -20,13 +20,13 @@
 #include "../krservices.h"
 #include <tqptrlist.h>
 #include <tqmap.h>
-#include <ktempfile.h>
+#include <tdetempfile.h>
 #include <kstandarddirs.h>
 
 class CS_Tool; // forward
-typedef void PREPARE_PROC_FUNC(KProcess& proc, CS_Tool *self, const TQStringList& files, 
+typedef void PREPARE_PROC_FUNC(TDEProcess& proc, CS_Tool *self, const TQStringList& files, 
 	const TQString checksumFile, bool recursive, const TQString& stdoutFileName, 
-	const TQString& stderrFileName,	const TQString& type=TQString());
+	const TQString& stderrFileName,	const TQString& type);
 typedef TQStringList GET_FAILED_FUNC(const TQStringList& stdOut, const TQStringList& stdErr);
 
 class CS_Tool {
@@ -51,7 +51,7 @@ public:
 };
 
 // handles md5sum and sha1sum
-void sumCreateFunc(KProcess& proc, CS_Tool *self, const TQStringList& files, 
+void sumCreateFunc(TDEProcess& proc, CS_Tool *self, const TQStringList& files, 
 	const TQString, bool recursive, const TQString& stdoutFileName, 
 	const TQString& stderrFileName, const TQString&) {
 	proc.setUseShell(true, "/bin/bash");
@@ -60,7 +60,7 @@ void sumCreateFunc(KProcess& proc, CS_Tool *self, const TQStringList& files,
 	proc << files << "1>" << stdoutFileName << "2>" << stderrFileName;	
 }
 
-void sumVerifyFunc(KProcess& proc, CS_Tool *self, const TQStringList& /* files */, 
+void sumVerifyFunc(TDEProcess& proc, CS_Tool *self, const TQStringList& /* files */, 
 	const TQString checksumFile, bool recursive, const TQString& stdoutFileName, 
 	const TQString& stderrFileName, const TQString& /* type */) {
 	proc.setUseShell(true, "/bin/bash");
@@ -86,7 +86,7 @@ TQStringList sumFailedFunc(const TQStringList& stdOut, const TQStringList& stdEr
 }
 
 // handles *deep binaries
-void deepCreateFunc(KProcess& proc, CS_Tool *self, const TQStringList& files, 
+void deepCreateFunc(TDEProcess& proc, CS_Tool *self, const TQStringList& files, 
 	const TQString, bool recursive, const TQString& stdoutFileName, 
 	const TQString& stderrFileName, const TQString&) {
 	proc.setUseShell(true, "/bin/bash");
@@ -95,7 +95,7 @@ void deepCreateFunc(KProcess& proc, CS_Tool *self, const TQStringList& files,
 	proc << "-l" << files << "1>" << stdoutFileName << "2>" << stderrFileName;
 }
 
-void deepVerifyFunc(KProcess& proc, CS_Tool *self, const TQStringList& files, 
+void deepVerifyFunc(TDEProcess& proc, CS_Tool *self, const TQStringList& files, 
 	const TQString checksumFile, bool recursive, const TQString& stdoutFileName, 
 	const TQString& stderrFileName, const TQString&) {
 	proc.setUseShell(true, "/bin/bash");
@@ -110,7 +110,7 @@ TQStringList deepFailedFunc(const TQStringList& stdOut, const TQStringList&/* st
 }
 
 // handles cfv binary
-void cfvCreateFunc(KProcess& proc, CS_Tool *self, const TQStringList& files, 
+void cfvCreateFunc(TDEProcess& proc, CS_Tool *self, const TQStringList& files, 
 	const TQString, bool recursive, const TQString& stdoutFileName, 
 	const TQString& stderrFileName, const TQString& type) {
 	proc.setUseShell(true, "/bin/bash");
@@ -119,7 +119,7 @@ void cfvCreateFunc(KProcess& proc, CS_Tool *self, const TQStringList& files,
 	proc << "-t" << type << "-f-" << "-U" << files << "1>" << stdoutFileName << "2>" << stderrFileName;	
 }
 
-void cfvVerifyFunc(KProcess& proc, CS_Tool *self, const TQStringList& /* files */, 
+void cfvVerifyFunc(TDEProcess& proc, CS_Tool *self, const TQStringList& /* files */, 
 	const TQString checksumFile, bool recursive, const TQString& stdoutFileName, 
 	const TQString& stderrFileName, const TQString&type) {
 	proc.setUseShell(true, "/bin/bash");
@@ -230,7 +230,7 @@ CreateChecksumDlg::CreateChecksumDlg(const TQStringList& files, bool containFold
 	// title (icon+text)	
 	TQHBoxLayout *hlayout = new TQHBoxLayout(layout, KDialogBase::spacingHint());
 	TQLabel *p = new TQLabel(plainPage());
-	p->setPixmap(krLoader->loadIcon("binary", KIcon::Desktop, 32));
+	p->setPixmap(krLoader->loadIcon("application-octet-stream", TDEIcon::Desktop, 32));
 	hlayout->addWidget(p);
 	TQLabel *l1 = new TQLabel(i18n("About to calculate checksum for the following files") + 
 		(containFolders ? i18n(" and folders:") : ":"), plainPage());
@@ -239,7 +239,7 @@ CreateChecksumDlg::CreateChecksumDlg(const TQStringList& files, bool containFold
 	++row;
 	
 	// file list
-	KListBox *lb = new KListBox(plainPage());
+	TDEListBox *lb = new TDEListBox(plainPage());
 	lb->insertStringList(files);
 	layout->addMultiCellWidget(lb, row, row, 0, 1);
 	++row;
@@ -262,14 +262,14 @@ CreateChecksumDlg::CreateChecksumDlg(const TQStringList& files, bool containFold
 	// else implied: run the process
 	tmpOut = new KTempFile(locateLocal("tmp", "krusader"), ".stdout" );
 	tmpErr = new KTempFile(locateLocal("tmp", "krusader"), ".stderr" );
-	KProcess proc;
+	TDEProcess proc;
 	CS_Tool *mytool = tools.at(method->currentItem());
 	mytool->create(proc, mytool, KrServices::quote(files), TQString(), containFolders, 
 		tmpOut->name(), tmpErr->name(), method->currentText());
 	
 	krApp->startWaiting(i18n("Calculating checksums ..."), 0, true);	
 	TQApplication::setOverrideCursor( KCursor::waitCursor() );
-	bool r = proc.start(KProcess::NotifyOnExit, KProcess::AllOutput);
+	bool r = proc.start(TDEProcess::NotifyOnExit, TDEProcess::AllOutput);
 	if (r) while ( proc.isRunning() ) {
 		usleep( 500 );
 		tqApp->processEvents();
@@ -331,7 +331,7 @@ MatchChecksumDlg::MatchChecksumDlg(const TQStringList& files, bool containFolder
 	// title (icon+text)	
 	TQHBoxLayout *hlayout = new TQHBoxLayout(layout, KDialogBase::spacingHint());
 	TQLabel *p = new TQLabel(plainPage());
-	p->setPixmap(krLoader->loadIcon("binary", KIcon::Desktop, 32));
+	p->setPixmap(krLoader->loadIcon("application-octet-stream", TDEIcon::Desktop, 32));
 	hlayout->addWidget(p);
 	TQLabel *l1 = new TQLabel(i18n("About to verify checksum for the following files") +
 		(containFolders ? i18n(" and folders:") : ":"), plainPage());
@@ -340,7 +340,7 @@ MatchChecksumDlg::MatchChecksumDlg(const TQStringList& files, bool containFolder
 	++row;
 	
 	// file list
-	KListBox *lb = new KListBox(plainPage());
+	TDEListBox *lb = new TDEListBox(plainPage());
 	lb->insertStringList(files);
 	layout->addMultiCellWidget(lb, row, row, 0, 1);
 	++row;
@@ -381,11 +381,11 @@ MatchChecksumDlg::MatchChecksumDlg(const TQStringList& files, bool containFolder
 	// else implied: run the process
 	tmpOut = new KTempFile(locateLocal("tmp", "krusader"), ".stdout" );
 	tmpErr = new KTempFile(locateLocal("tmp", "krusader"), ".stderr" );
-	KProcess proc;
+	TDEProcess proc;
 	mytool->verify(proc, mytool, KrServices::quote(files), KrServices::quote(file), containFolders, tmpOut->name(), tmpErr->name(), extension);
 	krApp->startWaiting(i18n("Verifying checksums ..."), 0, true);	
 	TQApplication::setOverrideCursor( KCursor::waitCursor() );
-	bool r = proc.start(KProcess::NotifyOnExit, KProcess::AllOutput);
+	bool r = proc.start(TDEProcess::NotifyOnExit, TDEProcess::AllOutput);
 	if (r) while ( proc.isRunning() ) {
 		usleep( 500 );
   		tqApp->processEvents();
@@ -437,7 +437,7 @@ VerifyResultDlg::VerifyResultDlg(const TQStringList& failed):
 	// create the icon and title
 	TQHBoxLayout *hlayout = new TQHBoxLayout(layout, KDialogBase::spacingHint());
 	TQLabel p(plainPage());
-	p.setPixmap(krLoader->loadIcon(errors ? "messagebox_critical" : "messagebox_info", KIcon::Desktop, 32));
+	p.setPixmap(krLoader->loadIcon(errors ? "messagebox_critical" : "messagebox_info", TDEIcon::Desktop, 32));
 	hlayout->addWidget(&p);
 	
 	TQLabel *l1 = new TQLabel((errors ? i18n("Errors were detected while verifying the checksums") :
@@ -450,7 +450,7 @@ VerifyResultDlg::VerifyResultDlg(const TQStringList& failed):
 		TQLabel *l3 = new TQLabel(i18n("The following files have failed:"), plainPage());
 		layout->addMultiCellWidget(l3, row, row, 0, 1);
 		++row;
-		KListBox *lb2 = new KListBox(plainPage());
+		TDEListBox *lb2 = new TDEListBox(plainPage());
 		lb2->insertStringList(failed);
 		layout->addMultiCellWidget(lb2, row, row, 0, 1);
 		++row;
@@ -475,7 +475,7 @@ ChecksumResultsDlg::ChecksumResultsDlg(const TQStringList& stdOut, const TQStrin
 	// create the icon and title
 	TQHBoxLayout *hlayout = new TQHBoxLayout(layout, KDialogBase::spacingHint());
 	TQLabel p(plainPage());
-	p.setPixmap(krLoader->loadIcon(errors ? "messagebox_critical" : "messagebox_info", KIcon::Desktop, 32));
+	p.setPixmap(krLoader->loadIcon(errors ? "messagebox_critical" : "messagebox_info", TDEIcon::Desktop, 32));
 	hlayout->addWidget(&p);
 	
 	TQLabel *l1 = new TQLabel((errors ? i18n("Errors were detected while creating the checksums") :
@@ -490,7 +490,7 @@ ChecksumResultsDlg::ChecksumResultsDlg(const TQStringList& stdOut, const TQStrin
 			layout->addMultiCellWidget(l2, row, row, 0, 1);
 			++row;
 		}
-		KListView *lv = new KListView(plainPage());
+		TDEListView *lv = new TDEListView(plainPage());
 		if(standardFormat){
 			lv->addColumn(i18n("Hash"));
 			lv->addColumn(i18n("File"));
@@ -502,9 +502,9 @@ ChecksumResultsDlg::ChecksumResultsDlg(const TQStringList& stdOut, const TQStrin
 			TQString line = (*it);
 			if(standardFormat) {
 				int space = line.find(' ');
-				new KListViewItem(lv, line.left(space), line.mid(space+2));
+				new TDEListViewItem(lv, line.left(space), line.mid(space+2));
 			} else {
-				new KListViewItem(lv, line);
+				new TDEListViewItem(lv, line);
 			}	
 		}
 		layout->addMultiCellWidget(lv, row, row, 0, 1);
@@ -522,7 +522,7 @@ ChecksumResultsDlg::ChecksumResultsDlg(const TQStringList& stdOut, const TQStrin
 		TQLabel *l3 = new TQLabel(i18n("Here are the errors received:"), plainPage());
 		layout->addMultiCellWidget(l3, row, row, 0, 1);
 		++row;
-		KListBox *lb = new KListBox(plainPage());
+		TDEListBox *lb = new TDEListBox(plainPage());
 		lb->insertStringList(stdErr);
 		layout->addMultiCellWidget(lb, row, row, 0, 1);
 		++row;
