@@ -49,13 +49,13 @@ YP   YD 88   YD ~Y8888P' `8888Y' YP   YP Y8888D' Y88888P 88   YD
 #include <kprogress.h>
 #include <kstatusbar.h>
 #include <kinputdialog.h>
-#include <kmessagebox.h>
-#include <klocale.h>
-#include <kpopupmenu.h>
+#include <tdemessagebox.h>
+#include <tdelocale.h>
+#include <tdepopupmenu.h>
 #include <tqdict.h>
 
 //////////////////////////////////////////////////////////////////////////
-//  The following is KrDetailedView's settings in KConfig:
+//  The following is KrDetailedView's settings in TDEConfig:
 // Group name: KrDetailedView
 //
 // Ext Column
@@ -87,11 +87,11 @@ YP   YD 88   YD ~Y8888P' `8888Y' YP   YP Y8888D' Y88888P 88   YD
 
 TQString KrDetailedView::ColumnName[ KrDetailedViewProperties::MAX_COLUMNS ];
 
-KrDetailedView::KrDetailedView( TQWidget *parent, bool &left, KConfig *cfg, const char *name ) :
-      KListView( parent, name ), KrView( cfg ), _currDragItem( 0L ), currentlyRenamedItem( 0 ),
+KrDetailedView::KrDetailedView( TQWidget *parent, bool &left, TDEConfig *cfg, const char *name ) :
+      TDEListView( parent, name ), KrView( cfg ), _currDragItem( 0L ), currentlyRenamedItem( 0 ),
       pressedItem( 0 ) {
 	setWidget( this );
-	_nameInKConfig=TQString( "KrDetailedView" ) + TQString( ( left ? "Left" : "Right" ) ) ;
+	_nameInTDEConfig=TQString( "KrDetailedView" ) + TQString( ( left ? "Left" : "Right" ) ) ;
 	krConfig->setGroup("Private");
 	if (krConfig->readBoolEntry("Enable Input Method", true))
 		setInputMethodEnabled(true);
@@ -112,12 +112,12 @@ void KrDetailedView::setup() {
    }
 
    /////////////////////////////// listview ////////////////////////////////////
-   { // use the {} so that KConfigGroupSaver will work correctly!
-      KConfigGroupSaver grpSvr( _config, "Look&Feel" );
+   { // use the {} so that TDEConfigGroupSaver will work correctly!
+      TDEConfigGroupSaver grpSvr( _config, "Look&Feel" );
       setFont( _config->readFontEntry( "Filelist Font", _FilelistFont ) );
       // decide on single click/double click selection
       if ( _config->readBoolEntry( "Single Click Selects", _SingleClickSelects ) &&
-           KGlobalSettings::singleClick() ) {
+           TDEGlobalSettings::singleClick() ) {
          connect( this, TQT_SIGNAL( executed( TQListViewItem* ) ), this, TQT_SLOT( slotExecuted( TQListViewItem* ) ) );
       } else {
          connect( this, TQT_SIGNAL( clicked( TQListViewItem* ) ), this, TQT_SLOT( slotClicked( TQListViewItem* ) ) );
@@ -139,7 +139,7 @@ void KrDetailedView::setup() {
    }
 
    // add whatever columns are needed to the listview
-   krConfig->setGroup( nameInKConfig() );
+   krConfig->setGroup( nameInTDEConfig() );
    
 	newColumn( KrDetailedViewProperties::Name );  // we always have a name
    setColumnWidthMode( COLUMN(Name), TQListView::Manual );
@@ -163,7 +163,7 @@ void KrDetailedView::setup() {
       newColumn( KrDetailedViewProperties::DateTime );
       setColumnWidthMode( COLUMN(DateTime), TQListView::Manual );
       //setColumnWidth( column( DateTime ), TQFontMetrics( font() ).width( "99/99/99  99:99" ) );
-      setColumnWidth( COLUMN(DateTime), TQFontMetrics( font() ).width( KGlobal::locale() ->formatDateTime(
+      setColumnWidth( COLUMN(DateTime), TQFontMetrics( font() ).width( TDEGlobal::locale() ->formatDateTime(
                          TQDateTime ( TQDate( 2099, 12, 29 ), TQTime( 23, 59 ) ) ) ) + 3 );
    }
    if ( _config->readBoolEntry( "Perm Column", _PermColumn ) ) {
@@ -193,7 +193,7 @@ void KrDetailedView::setup() {
    setTooltipColumn( COLUMN(Name) );
    setDropVisualizer(false);
    setDropHighlighter(true);
-   setSelectionModeExt( KListView::FileManager );
+   setSelectionModeExt( TDEListView::FileManager );
    setAllColumnsShowFocus( true );
    setShowSortIndicator( true );
    header() ->setStretchEnabled( true, COLUMN(Name) );
@@ -357,7 +357,7 @@ void KrDetailedView::addItems( vfs *v, bool addUpDir ) {
 
    if ( !currentItem )
       currentItem = firstChild();
-   KListView::setCurrentItem( currentItem );
+   TDEListView::setCurrentItem( currentItem );
    ensureItemVisible( currentItem );
 
    op()->emitItemDescription( statusText );
@@ -374,7 +374,7 @@ TQString KrDetailedView::getCurrentItem() const {
 void KrDetailedView::setCurrentItem( const TQString& name ) {
    KrDetailedViewItem * it = dynamic_cast<KrDetailedViewItem*>(_dict[ name ]);
    if ( it )
-      KListView::setCurrentItem( it );
+      TDEListView::setCurrentItem( it );
 }
 
 void KrDetailedView::clear() {
@@ -388,7 +388,7 @@ void KrDetailedView::clear() {
    /* KDE HACK END */
 
    op()->emitSelectionChanged(); /* to avoid rename crash at refresh */
-   KListView::clear();
+   TDEListView::clear();
    KrView::clear();
 }
 
@@ -423,7 +423,7 @@ void KrDetailedView::setSortMode( KrViewProperties::SortSpec mode ) {
                         if ( mode & KrViewProperties::Group )
                            cl = COLUMN( Group );
    setSorting( cl, ascending );
-   KListView::sort();
+   TDEListView::sort();
 }
 
 void KrDetailedView::slotClicked( TQListViewItem *item ) {
@@ -431,7 +431,7 @@ void KrDetailedView::slotClicked( TQListViewItem *item ) {
 
    if ( !modifierPressed ) {
       if ( singleClicked && !renameTimer.isActive() ) {
-         KConfig * config = KGlobal::config();
+         TDEConfig * config = TDEGlobal::config();
          config->setGroup( "KDE" );
          int doubleClickInterval = config->readNumEntry( "DoubleClickInterval", 400 );
 
@@ -470,7 +470,7 @@ void KrDetailedView::prepareForPassive() {
    CANCEL_TWO_CLICK_RENAME;
    if ( renameLineEdit() ->isVisible() )
       renameLineEdit() ->clearFocus();
-   KConfigGroupSaver grpSvr( _config, "Look&Feel" );
+   TDEConfigGroupSaver grpSvr( _config, "Look&Feel" );
    if ( _config->readBoolEntry( "New Style Quicksearch", _NewStyleQuicksearch ) ) {
       if ( MAIN_VIEW ) {
          if ( ACTIVE_PANEL ) {
@@ -497,7 +497,7 @@ void KrDetailedView::handleQuickSearchEvent( TQKeyEvent * e ) {
          case Key_Insert:
          {
             TQKeyEvent ev = TQKeyEvent( TQKeyEvent::KeyPress, Key_Space, 0, 0 );
-            KListView::keyPressEvent( & ev );
+            TDEListView::keyPressEvent( & ev );
             ev = TQKeyEvent( TQKeyEvent::KeyPress, Key_Down, 0, 0 );
             keyPressEvent( & ev );
             break;
@@ -627,7 +627,7 @@ void KrDetailedView::contentsMousePressEvent( TQMouseEvent * e ) {
    }
 
    // stop quick search in case a mouse click occured
-   KConfigGroupSaver grpSvr( _config, "Look&Feel" );
+   TDEConfigGroupSaver grpSvr( _config, "Look&Feel" );
    if ( _config->readBoolEntry( "New Style Quicksearch", _NewStyleQuicksearch ) ) {
       if ( MAIN_VIEW ) {
          if ( ACTIVE_PANEL ) {
@@ -680,7 +680,7 @@ void KrDetailedView::contentsMousePressEvent( TQMouseEvent * e ) {
      if( newCurrent )                 // save the name of the file
        name = static_cast<KrDetailedViewItem*>( newCurrent ) ->name();
 
-     KListView::contentsMousePressEvent( e );
+     TDEListView::contentsMousePressEvent( e );
 
      if( name.isEmpty() || _dict.find( name ) == 0 ) // is the file still valid?
        newCurrent = 0;                // if not, don't do any crash...
@@ -717,7 +717,7 @@ void KrDetailedView::contentsMousePressEvent( TQMouseEvent * e ) {
 void KrDetailedView::contentsMouseReleaseEvent( TQMouseEvent * e ) {
   if (e->button() == Qt::RightButton)
     contextMenuTimer.stop();
-  KListView::contentsMouseReleaseEvent( e );
+  TDEListView::contentsMouseReleaseEvent( e );
 
   if( pressedItem ) {
     TQPoint vp = contentsToViewport( e->pos() );
@@ -788,13 +788,13 @@ void KrDetailedView::contentsMouseMoveEvent ( TQMouseEvent * e ) {
            emit onViewport();
       }
       else
-         KListView::contentsMouseMoveEvent( e );
+         TDEListView::contentsMouseMoveEvent( e );
 }
 
 void KrDetailedView::contentsWheelEvent( TQWheelEvent * e ) {
    if ( !_focused )
       op()->emitNeedFocus();
-   KListView::contentsWheelEvent( e );
+   TDEListView::contentsWheelEvent( e );
 }
 
 void KrDetailedView::handleContextMenu( TQListViewItem * it, const TQPoint & pos, int ) {
@@ -821,7 +821,7 @@ void KrDetailedView::showContextMenu()
 }
 
 KrViewItem *KrDetailedView::getKrViewItemAt( const TQPoint & vp ) {
-   return dynamic_cast<KrViewItem*>( KListView::itemAt( vp ) );
+   return dynamic_cast<KrViewItem*>( TDEListView::itemAt( vp ) );
 }
 
 bool KrDetailedView::acceptDrag( TQDropEvent* ) const {
@@ -845,7 +845,7 @@ void KrDetailedView::contentsDropEvent( TQDropEvent * e ) {
    e->setPoint( contentsToViewport( e->pos() ) );
    op()->emitGotDrop(e);
    e->ignore();
-   KListView::contentsDropEvent( e );
+   TDEListView::contentsDropEvent( e );
 }
 
 void KrDetailedView::contentsDragMoveEvent( TQDragMoveEvent * e ) {
@@ -853,7 +853,7 @@ void KrDetailedView::contentsDragMoveEvent( TQDragMoveEvent * e ) {
    if( _currDragItem && !_currDragItem->VF->vfile_isDir() )
      _currDragItem = 0;
    
-   KListView::contentsDragMoveEvent( e );
+   TDEListView::contentsDragMoveEvent( e );
 }
 
 void KrDetailedView::imStartEvent(TQIMEvent* e)
@@ -862,9 +862,9 @@ void KrDetailedView::imStartEvent(TQIMEvent* e)
     ACTIVE_PANEL->quickSearch->myIMStartEvent( e );
     return ;
   }else {
-    KConfigGroupSaver grpSvr( _config, "Look&Feel" );
+    TDEConfigGroupSaver grpSvr( _config, "Look&Feel" );
     if ( !_config->readBoolEntry( "New Style Quicksearch", _NewStyleQuicksearch ) )
-      KListView::imStartEvent( e );
+      TDEListView::imStartEvent( e );
     else {
 							// first, show the quicksearch if its hidden
       if ( ACTIVE_PANEL->quickSearch->isHidden() ) {
@@ -921,7 +921,7 @@ void KrDetailedView::keyPressEvent( TQKeyEvent * e ) {
 					TQListView::setCurrentItem( i );
 					TQListView::ensureItemVisible( i );
 				}
-         } else KListView::keyPressEvent(e);
+         } else TDEListView::keyPressEvent(e);
          break;
          case Key_Down :
          if ( e->state() == ControlButton || e->state() == ( ControlButton | ShiftButton ) ) { // let the panel handle it - jump to command line
@@ -933,7 +933,7 @@ void KrDetailedView::keyPressEvent( TQKeyEvent * e ) {
             if ( e->state() == ShiftButton ) setSelected( i, !i->isSelected() );
             i = i->itemBelow();
          if ( i ) {TQListView::setCurrentItem( i ); TQListView::ensureItemVisible( i ); }
-         } else KListView::keyPressEvent(e);
+         } else TDEListView::keyPressEvent(e);
          break;
          case Key_Next:  if (!KrSelectionMode::getSelectionHandler()->useTQTSelection()){
             TQListViewItem * i = currentItem(), *j;
@@ -943,7 +943,7 @@ void KrDetailedView::keyPressEvent( TQKeyEvent * e ) {
             for ( int page = visibleHeight() / r.height() - 1; page > 0 && ( j = i->itemBelow() ); --page )
                i = j;
             if ( i ) {TQListView::setCurrentItem( i ); TQListView::ensureItemVisible( i ); }
-         } else KListView::keyPressEvent(e);
+         } else TDEListView::keyPressEvent(e);
          break;
          case Key_Prior:  if (!KrSelectionMode::getSelectionHandler()->useTQTSelection()){
             TQListViewItem * i = currentItem(), *j;
@@ -953,13 +953,13 @@ void KrDetailedView::keyPressEvent( TQKeyEvent * e ) {
             for ( int page = visibleHeight() / r.height() - 1; page > 0 && ( j = i->itemAbove() ); --page )
                i = j;
             if ( i ) {TQListView::setCurrentItem( i ); TQListView::ensureItemVisible( i ); }
-         } else KListView::keyPressEvent(e);
+         } else TDEListView::keyPressEvent(e);
          break;
          case Key_Home:  if (!KrSelectionMode::getSelectionHandler()->useTQTSelection()){
             if ( e->state() & ShiftButton )  /* Shift+Home */
             {
                clearSelection();
-               KListView::keyPressEvent( e );
+               TDEListView::keyPressEvent( e );
                op()->emitSelectionChanged();
                triggerUpdate();
                break;
@@ -967,13 +967,13 @@ void KrDetailedView::keyPressEvent( TQKeyEvent * e ) {
                TQListViewItem * i = firstChild();
                if ( i ) {TQListView::setCurrentItem( i ); TQListView::ensureItemVisible( i ); }
             }
-         } else KListView::keyPressEvent(e);
+         } else TDEListView::keyPressEvent(e);
          break;
          case Key_End:  if (!KrSelectionMode::getSelectionHandler()->useTQTSelection()){
             if ( e->state() & ShiftButton )  /* Shift+End */
             {
                clearSelection();
-               KListView::keyPressEvent( e );
+               TDEListView::keyPressEvent( e );
                op()->emitSelectionChanged();
                triggerUpdate();
                break;
@@ -986,7 +986,7 @@ void KrDetailedView::keyPressEvent( TQKeyEvent * e ) {
             if ( i ) {TQListView::setCurrentItem( i ); TQListView::ensureItemVisible( i ); }
                break;
             }
-         } else KListView::keyPressEvent(e);
+         } else TDEListView::keyPressEvent(e);
          break;
          case Key_Enter :
          case Key_Return : {
@@ -1048,7 +1048,7 @@ void KrDetailedView::keyPressEvent( TQKeyEvent * e ) {
             return ;         // safety
          }
          //case Key_Up :
-         //KListView::keyPressEvent( e );
+         //TDEListView::keyPressEvent( e );
          //break;
 /*#ifndef _newSelectionHandling
          case Key_Down :
@@ -1056,7 +1056,7 @@ void KrDetailedView::keyPressEvent( TQKeyEvent * e ) {
             e->ignore();
             break;
          } else
-            KListView::keyPressEvent( e );
+            TDEListView::keyPressEvent( e );
          break;
 #endif*/
          case Key_Delete :                   // kill file
@@ -1065,11 +1065,11 @@ void KrDetailedView::keyPressEvent( TQKeyEvent * e ) {
          break ;
          case Key_Insert : {
             if (KrSelectionMode::getSelectionHandler()->insertMovesDown())
-               KListView::keyPressEvent( e );
+               TDEListView::keyPressEvent( e );
             else
             {
                TQKeyEvent ev = TQKeyEvent( TQKeyEvent::KeyPress, Key_Space, 0, 0 );
-               KListView::keyPressEvent( & ev );
+               TDEListView::keyPressEvent( & ev );
             }
             break ; 
          }
@@ -1079,10 +1079,10 @@ void KrDetailedView::keyPressEvent( TQKeyEvent * e ) {
                if (KrSelectionMode::getSelectionHandler()->spaceMovesDown())
                {
                   TQKeyEvent ev = TQKeyEvent( TQKeyEvent::KeyPress, Key_Insert, 0, 0 );
-                  KListView::keyPressEvent( & ev );
+                  TDEListView::keyPressEvent( & ev );
                }
                else
-                  KListView::keyPressEvent( e );
+                  TDEListView::keyPressEvent( e );
                break ; 
             }
             if ( viewItem->VF->vfile_isDir() && viewItem->VF->vfile_getSize() <= 0 && 
@@ -1092,7 +1092,7 @@ void KrDetailedView::keyPressEvent( TQKeyEvent * e ) {
                // there's a folder we can't enter (permissions). in that case, the returned
                // size will not be correct.
                //
-               KIO::filesize_t totalSize = 0;
+               TDEIO::filesize_t totalSize = 0;
                unsigned long totalFiles = 0, totalDirs = 0;
                TQStringList items;
                items.push_back( viewItem->name() );
@@ -1108,15 +1108,15 @@ void KrDetailedView::keyPressEvent( TQKeyEvent * e ) {
 mark:       if (KrSelectionMode::getSelectionHandler()->spaceMovesDown())
             {
                TQKeyEvent ev = TQKeyEvent( TQKeyEvent::KeyPress, Key_Insert, 0, 0 );
-               KListView::keyPressEvent( & ev );
+               TDEListView::keyPressEvent( & ev );
             }
             else
-               KListView::keyPressEvent( e );
+               TDEListView::keyPressEvent( e );
          }
          break;
          case Key_A :                 // mark all
          if ( e->state() == ControlButton ) {
-            KListView::keyPressEvent( e );
+            TDEListView::keyPressEvent( e );
             updateView();
             break;
          }
@@ -1135,9 +1135,9 @@ mark:       if (KrSelectionMode::getSelectionHandler()->spaceMovesDown())
             //if ( _config->readBoolEntry( "Do Quicksearch", _DoQuicksearch ) ) {
                // are we using krusader's classic quicksearch, or wincmd style?
                {
-						KConfigGroupSaver grpSvr( _config, "Look&Feel" );
+						TDEConfigGroupSaver grpSvr( _config, "Look&Feel" );
 						if ( !_config->readBoolEntry( "New Style Quicksearch", _NewStyleQuicksearch ) )
-							KListView::keyPressEvent( e );
+							TDEListView::keyPressEvent( e );
 						else {
 							// first, show the quicksearch if its hidden
 							if ( ACTIVE_PANEL->quickSearch->isHidden() ) {
@@ -1162,7 +1162,7 @@ mark:       if (KrSelectionMode::getSelectionHandler()->spaceMovesDown())
                ACTIVE_PANEL->quickSearch->clear();
                krDirUp->setEnabled( true );
             }
-            KListView::keyPressEvent( e );
+            TDEListView::keyPressEvent( e );
          }
    }
    // emit the new item description
@@ -1183,7 +1183,7 @@ void KrDetailedView::rename( TQListViewItem * item, int c ) {
    renameLineEdit()->setBackgroundMode(TQt::FixedColor);
    renameLineEdit()->setPaletteBackgroundColor(TQt::white);
    renameLineEdit()->setPaletteForegroundColor(TQt::black);
-   KListView::rename( item, c );
+   TDEListView::rename( item, c );
    renameLineEdit() ->selectAll();
 }
 
@@ -1212,7 +1212,7 @@ void KrDetailedView::renameCurrentItem() {
    if ( c >= 0 ) {
       rename( static_cast<TQListViewItem*>( it ), c );
       // if applicable, select only the name without extension
-      KConfigGroupSaver svr(krConfig,"Look&Feel");
+      TDEConfigGroupSaver svr(krConfig,"Look&Feel");
       if (!krConfig->readBoolEntry("Rename Selects Extension", true)) {
 	if (it->hasExtension() && !it->VF->vfile_isDir() ) 
 		renameLineEdit()->setSelection(0, it->name().findRev(it->extension())-1);
@@ -1272,7 +1272,7 @@ void KrDetailedView::quickSearch( const TQString & str, int direction ) {
    KrViewItem * item = getCurrentKrViewItem();
    if (!item)
       return;
-   KConfigGroupSaver grpSvr( _config, "Look&Feel" );
+   TDEConfigGroupSaver grpSvr( _config, "Look&Feel" );
    bool caseSensitive = _config->readBoolEntry( "Case Sensitive Quicksearch", _CaseSensitiveQuicksearch );
    if ( !direction ) {
       if ( caseSensitive ? item->name().startsWith( str ) : item->name().lower().startsWith( str.lower() ) )
@@ -1333,9 +1333,9 @@ void KrDetailedView::refreshColors() {
       setAlternateBackground( cg.background() );
    } else {
       // KDE default is choosen: set back the background color
-      setPaletteBackgroundColor( KGlobalSettings::baseColor() );
+      setPaletteBackgroundColor( TDEGlobalSettings::baseColor() );
       // Set the alternate color to its default or to an invalid color, to turn alternate the background off.
-      setAlternateBackground( alternateBackgroundEnabled ? KGlobalSettings::alternateBackgroundColor() : TQColor() );
+      setAlternateBackground( alternateBackgroundEnabled ? TDEGlobalSettings::alternateBackgroundColor() : TQColor() );
    }
 }
 
@@ -1351,7 +1351,7 @@ bool KrDetailedView::event( TQEvent *e ) {
          default:
          CANCEL_TWO_CLICK_RENAME;
    }
-   return KListView::event( e );
+   return TDEListView::event( e );
 }
 
 bool KrDetailedView::eventFilter( TQObject * watched, TQEvent * e )
@@ -1380,7 +1380,7 @@ bool KrDetailedView::eventFilter( TQObject * watched, TQEvent * e )
     }
     return FALSE;
   }
-  return KListView::eventFilter( watched, e );
+  return TDEListView::eventFilter( watched, e );
 }
 
 void KrDetailedView::makeItemVisible( const KrViewItem *item ) {
@@ -1390,13 +1390,13 @@ void KrDetailedView::makeItemVisible( const KrViewItem *item ) {
 
 void KrDetailedView::initOperator() {
 	_operator = new KrViewOperator(this, this);
-	// klistview emits selection changed, so chain them to operator
+	// tdelistview emits selection changed, so chain them to operator
 	connect(this, TQT_SIGNAL(selectionChanged()), _operator, TQT_SIGNAL(selectionChanged()));
 }
 
 void KrDetailedView::initProperties() {
 	_properties = new KrDetailedViewProperties;
-	KConfigGroupSaver grpSvr( _config, "Look&Feel" );	
+	TDEConfigGroupSaver grpSvr( _config, "Look&Feel" );	
 	for (int i=0; i<KrDetailedViewProperties::MAX_COLUMNS;++i)
 		PROPS->column[i]=-1;	
 	PROPS->displayIcons = _config->readBoolEntry( "With Icons", _WithIcons );
@@ -1433,7 +1433,7 @@ void KrDetailedView::initProperties() {
 
 void KrDetailedView::selectColumns()
 {
-  KPopupMenu popup( this );
+  TDEPopupMenu popup( this );
   popup.insertTitle( i18n("Columns"));
   
   bool refresh = false;
@@ -1473,7 +1473,7 @@ void KrDetailedView::selectColumns()
   
   int result=popup.exec(TQCursor::pos());
 
-  krConfig->setGroup( nameInKConfig() );
+  krConfig->setGroup( nameInTDEConfig() );
   
   switch( result - COLUMN_POPUP_IDS )
   {
@@ -1562,7 +1562,7 @@ void KrDetailedView::slotSortOrderChanged(int col) {
 			sp = KrViewProperties::Owner; break;
 		case KrDetailedViewProperties::Group:
 			sp = KrViewProperties::Group; break;
-		default: qFatal("slotSortOrderChanged: unknown column");
+		default: tqFatal("slotSortOrderChanged: unknown column");
 	}
 	if (sortMode() & KrViewProperties::DirsFirst) 
 		sp = static_cast<KrViewProperties::SortSpec>(sp | KrViewProperties::DirsFirst);
